declare module BA.Ui {
    /**
     * Class to set focus on selected elements
     */
    class DefaultFocus {
        /**
         * Set the default focus in the given area for the best matching element
         * @param area          The area we need to process the default focus
         * @param retries       The number of retries (default = 3)
         * @param parentElement The parent element where to search for the input fields for the focus
         * @param position      Position of the desired element (if we have multiple elements we could use for the default focus)
         * @param callback      Callback function after the focus happens
         */
        static Focus(area: BA.Ui.DefaultFocus.Area, retries?: number, parentElement?: HTMLElement, position?: number, callback?: Function): void;
        private static query;
        /**
         * Set focus on elements that are within a form.
         * @param retries The number of retries (default = 3)
         */
        private static FocusOnForm;
        /**
         * Set focus on elements that are within a dialog.
         * @param retries The number of retries (default = 3)
         */
        private static FocusOnDialog;
        /**
         * Set focus on the first input element within a grid
         * @param retries           The number of retries (default = 3)
         * @param scrollIntoView    Should we use 'scrollIntoView' or let the browser auto handle this
         * @param grid              The grid we need to process. If nothing is specified we use the main grid view.
         */
        private static FocusOnGrid;
        /**
         * Set the default focus on sub records
         * @param subRecordContainer The element containing the sub records we need to set the default focus
         * @param retries The number of retries (default = 3)
         * @param index The index of the subrecord we need to set the default focus (if no index is specified we use the last one)
         */
        private static FocusOnSubRecord;
        /**
         * Set focus on first element in the designer properties form.
         * @param retries The number of retries (default = 3)
         * @param form The form containing the inpuf fields we need to set focus to. If nothing is specified we use the designer properties form.
         */
        private static FocusOnDesigner;
        /**
        * Runs the default focus in a page.
        * @param retries The number of retries (default = 3)
        */
        private static FocusOnPage;
        /**
         * Set focus on first input element (if any) in the widget.
         * @param retries The number of retries (default = 3)
         */
        private static FocusOnWidget;
        /**
         * If we have an element we can focus it and maybe even set the selection range
         * (to set the cursor at the last position in the field)
         * @param element The element we possibly found from the area in the 'Focus'-method
         * @param scrollIntoView Should we use 'scrollIntoView' or let the autoscroll of the browser happen?
         */
        private static ProcessElement;
        /**
         * Finds the first really visible element in a list of elements
         * @param elements  NodeList with elements (in fact: HTMLElements)
         */
        private static FilterFirstVisible;
    }
    /**
     * Area enum
     */
    namespace DefaultFocus {
        enum Area {
            Designer = 0,
            Dialog = 1,
            Form = 2,
            Grid = 3,
            Page = 4,
            SubRecord = 5,
            Widget = 6
        }
    }
}
