declare module BA.Ui.Widgets {
    /**
     * Class for NavigationMenuWidget
     * */
    class NavigationMenuWidget extends Widget {
        color: string;
        highlightColor: string;
        widgetId: string;
        menuWrapperIdSelector: string;
        navConfigId: string;
        widgetSize: string;
        maxCols: number | null;
        /**
         * Initialize Navigation Menu
         * */
        Init(): void;
        /**
         * Attach the events needed for the drag and drop interaction of google maps widgets.
         */
        AttachDragAndDropEvents(): void;
        Unload(): void;
        OnContentLoaded(): void;
        /**
         * Updates the alternatives to menu items when the tab is activated
         */
        private OnTabActivated;
        /**
         * Updates the alternatives of a menu item.
         *
         * @param id Id of the menu item whose alternatives will be updated.
         * @param alternatives New alternatives for the menu item.
         */
        UpdateAlternativesOfMenuItem(id: string, alternatives: any): void;
        /**
         * Generates the html of an alternative item.
         *
         * @param navigateUrl Url for the alternative item.
         * @param iconName Icon name for the alternative item.
         * @param caption Caption for the alternative item.
         * @param iconColor Color of the icon.
         */
        GetAlternativeItemHtml(navigateUrl: string, iconName: string, caption: string, iconColor: string): string;
        /**
         * Handles the click of a menu item to either open the url or to execute the corresponding action.
         *
         * @param element Clicked element.
         * @param event Event object.
         */
        private OnItemClick;
        /**
         * Attaches the corresponding click handlers to the menu items.
         */
        private AttachClickMenuItems;
        /**
         * Attaches the corresponding click handlers to the alternative items.
         */
        private AttachClickAlternativeItems;
        /**
         * Moves the alternatives menu to the page DOM element.
         */
        private MoveAlternativeMenus;
        /**
         * Handles the hover over alternative menu items
         *
         * @param $altMenu
         */
        private: any;
        MouseLeaveAlternativeItem($altMenu: JQuery): void;
        /**
         * Attaches the corresponding hover handlers to the alternative items.
         */
        private AttachHoverAlternativeItems;
        /**
         * Get minimum width of individual Navigation item
         * */
        private GetMinWidth;
        /**
         * Get maximum width of individual Navigation item
         * */
        private GetMaxWidth;
        /**
         * Toggle menu item
         * @param menuItem The menu item to toggle.
         */
        ToggleMenuItem(menuItem: JQuery, e: any): void;
        /** Ensure Responsiveness for Navigation Menu */
        ActResponsive(): void;
        /**
         * Change order of Navigation items
         * @param containersPerRow number of containers per row
         */
        ChangeFlexboxOrder(containersPerRow: number): void;
        /**
         * Get the number of columns that fit in a row
         * @param width width of container
         */
        GetColumns(width: number): number;
        /**
         * Aply class to columns
         * @param columnsClass
         * @param element
         */
        ApplyColumnsClass(columnsClass: string, element: JQuery): void;
    }
}
